// AUTO-GENERATED BY UpdateGenVersion.bat 50b5548b099ee6f033816fc417621e915465494d
const char GenVersion_Version[] = "0.4.4-dev";
const char GenVersion_Commit[] = "50b5548b099ee6f033816fc417621e915465494d";
